@@ -5,7 +5,7 @@ from enum import Enum
 from random import choice
 
 import typer
-from psycopg import connect, conninfo
+from psycopg import connect, extras
 from pymongo import MongoClient
 from rich.console import Console
 
@@ -13,7 +13,7 @@ from np_data_validator_2 import version
 from np_data_validator_2.core import (
     create_validation_manifest_from_json,
     get_validation_results,
-    validate_lims,
+    validate_lims_upload,
     validate_local_experiment,
 )
 from np_data_validator_2.transformers import from_AssetValidationResult
@@ -86,8 +86,8 @@ def validate_lims(
     lims_id: str,
 ) -> None:
     client = MongoClient(db_address)
-    conn = connect(**conninfo.conninfo_to_dict(lims_address))
-    with conn.cursor() as cursor:
+    conn = connect(lims_address)
+    with conn.cursor(cursor_factory=extras.RealDictCursor) as cursor:
         validated = validate_lims_upload(
             client,
             cursor,
